<?php
if ( class_exists( 'myCRED_Hook' ) ) :
	class wti_like_post_pro_mycred extends myCRED_Hook {
 
		/**
		 * Construct
		 */
		function __construct( $hook_prefs, $type = 'mycred_default' ) {
 			global $wpdb;
			$this->wpdb = $wpdb;

			parent::__construct( array(
				'id'       => 'wti_like_post_pro',
				'defaults' => array(
					'wti_add_like'    => array(
						'creds'  => 1,
						'log'    => '%plural% for liking a content',
						'limit'  => '0/x'
					),
					'wti_get_like'  => array(
						'creds'  => 1,
						'log'    => '%plural% for getting liked from a content',
						'limit'  => '0/x'
					),
					'wti_add_unlike'  => array(
						'creds'  => -1,
						'log'    => '%plural% deduction for unliking a content'
					),
					'wti_get_unlike'  => array(
						'creds'  => -1,
						'log'    => '%plural% for getting Unliked from a content'
					)
				)
			), $hook_prefs, $type );
		}
 
		/**
		 * Run Actions
		 *
		 * @since		2.3
		 */
		public function run() {
			if ( ( $this->prefs['wti_add_like']['creds'] != 0 || $this->prefs['wti_get_like']['creds'] != 0 ) || 
				( $this->prefs['wti_add_unlike']['creds'] != 0 || $this->prefs['wti_get_unlike']['creds'] != 0 ) ) {
				add_action( 'wti_like_post_mycred_action', array( $this, 'wti_like_post_mycred_action' ), 10, 3 );
			}
		}
		
		/**
		 * Process voting points activity
		 *
		 * @since		2.3
		 */
		public function wti_like_post_mycred_action($id, $key, $user_id) {
			$author_id = 0;

			// Check for exclusion
			if ( $this->core->exclude_user( $user_id ) ) return;			
			
			if ( $key == 'like' || $key == 'unlike' ) {
				$author_id = get_post_field( 'post_author', $id );
			}
			
			if ( $user_id != $author_id ) {
				$add_action = ( $key == 'like' ) ? 'wti_add_like' : 'wti_add_unlike';
				$get_action = ( $key == 'like' ) ? 'wti_get_like' : 'wti_get_unlike';

				// Award the user liking
				if ( $this->prefs[$add_action]['creds'] != 0) {
					// Limit
					if ( $this->over_hook_limit( $add_action, $add_action, $user_id ) ) return;

					// Make sure this is unique event
					if ( ! $this->core->has_entry( $add_action, $id, $user_id ) ) {
						// Execute
						$this->core->add_creds(
							$add_action,
							$user_id,
							$this->prefs[$add_action]['creds'],
							$this->prefs[$add_action]['log'],
							$id,
							array( 'ref_type' => $key ),
							$this->mycred_type
						);
					}
				}

				// Award post author for being liked/unliked
				if ( $this->prefs[$get_action]['creds'] != 0 && $author_id != 0 ) {
					// Make sure this is unique event
					if ( $this->over_hook_limit( $get_action, $get_action, $author_id ) ) return;
					
					// Make sure this is unique event
					if ( ! $this->core->has_entry( $get_action, $id, $author_id ) ) {
						// Execute
						$this->core->add_creds(
							$get_action,
							$author_id,
							$this->prefs[$get_action]['creds'],
							$this->prefs[$get_action]['log'],
							$id,
							array( 'ref_type' => $key, 'by' => $user_id ),
							$this->mycred_type
						);
					}
				}
			}
		}
		
		/**
		 * Preference for wti_like_post_pro Hook
		 *
		 * @since		2.3
		 */
		public function preferences() {
			$prefs = $this->prefs;

			?>
			<label class="subheader"><?php echo _e( 'Points for Liking content', 'wti-like-post' ); ?></label>
			<ol>
				<li>
					<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'wti_add_like' => 'creds' ) ); ?>" id="<?php echo $this->field_id( array( 'wti_add_like' => 'creds' ) ); ?>" value="<?php echo $this->core->number( $prefs['wti_add_like']['creds'] ); ?>" size="8" /></div>
				</li>
				<li class="empty"></li>
				<li>
					<label for="<?php echo $this->field_id( array( 'wti_add_like' => 'limit' ) ); ?>"><?php _e( 'Limit', 'wti-like-post' ); ?></label>
					<?php echo $this->hook_limit_setting( $this->field_name( array( 'wti_add_like' => 'limit' ) ), $this->field_id( array( 'wti_add_like' => 'limit' ) ), $prefs['wti_add_like']['limit'] ); ?>
				</li>	
				<li class="empty"></li>
				<li>
					<label for="<?php echo $this->field_id( array( 'wti_add_like' => 'log' ) ); ?>"><?php _e( 'Log template', 'mycred' ); ?></label>
					<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'wti_add_like' => 'log' ) ); ?>" id="<?php echo $this->field_id( array( 'wti_add_like' => 'log' ) ); ?>" value="<?php echo esc_attr( $prefs['wti_add_like']['log'] ); ?>" class="long" /></div>
					<span class="description"><?php echo $this->available_template_tags( array( 'general' ) ); ?></span>
				</li>
			</ol>
			<label class="subheader"><?php _e( 'Points for Author Who Get Liked', 'wti-like-post' ); ?></label>
			<ol>
				<li>
					<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'wti_get_like' => 'creds' ) ); ?>" id="<?php echo $this->field_id( array( 'wti_get_like' => 'creds' ) ); ?>" value="<?php echo $this->core->number( $prefs['wti_get_like']['creds'] ); ?>" size="8" /></div>
				</li>
				<li class="empty"></li>
				<li>
					<label for="<?php echo $this->field_id( array( 'wti_get_like' => 'limit' ) ); ?>"><?php _e( 'Limit', 'wti-like-post' ); ?></label>
					<?php echo $this->hook_limit_setting( $this->field_name( array( 'wti_get_like' => 'limit' ) ), $this->field_id( array( 'wti_get_like' => 'limit' ) ), $prefs['wti_get_like']['limit'] ); ?>
				</li>		
				<li class="empty"></li>
				<li>
					<label for="<?php echo $this->field_id( array( 'wti_get_like' => 'log' ) ); ?>"><?php _e( 'Log template', 'mycred' ); ?></label>
					<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'wti_get_like' => 'log' ) ); ?>" id="<?php echo $this->field_id( array( 'wti_get_like' => 'log' ) ); ?>" value="<?php echo esc_attr( $prefs['wti_get_like']['log'] ); ?>" class="long" /></div>
					<span class="description"><?php echo $this->available_template_tags( array( 'general' ) ); ?></span>
				</li>
			</ol>
			<label class="subheader"><?php echo _e( 'Points for unliking content', 'wti-like-post' ); ?></label>
			<ol>
				<li>
					<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'wti_add_unlike' => 'creds' ) ); ?>" id="<?php echo $this->field_id( array( 'wti_add_unlike' => 'creds' ) ); ?>" value="<?php echo $this->core->number( $prefs['wti_add_unlike']['creds'] ); ?>" size="8" /></div>
				</li>
				<li class="empty"></li>
				<li>
					<label for="<?php echo $this->field_id( array( 'wti_add_unlike' => 'log' ) ); ?>"><?php _e( 'Log template', 'mycred' ); ?></label>
					<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'wti_add_unlike' => 'log' ) ); ?>" id="<?php echo $this->field_id( array( 'wti_add_unlike' => 'log' ) ); ?>" value="<?php echo esc_attr( $prefs['wti_add_unlike']['log'] ); ?>" class="long" /></div>
					<span class="description"><?php echo $this->available_template_tags( array( 'general' ) ); ?></span>
				</li>
			</ol>
			<label class="subheader"><?php _e( 'Points for Author Who Get Unliked', 'wti-like-post' ); ?></label>
			<ol>
				<li>
					<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'wti_get_unlike' => 'creds' ) ); ?>" id="<?php echo $this->field_id( array( 'wti_get_unlike' => 'creds' ) ); ?>" value="<?php echo $this->core->number( $prefs['wti_get_unlike']['creds'] ); ?>" size="8" /></div>
				</li>
				<li class="empty"></li>
				<li>
					<label for="<?php echo $this->field_id( array( 'wti_get_unlike' => 'log' ) ); ?>"><?php _e( 'Log template', 'mycred' ); ?></label>
					<div class="h2"><input type="text" name="<?php echo $this->field_name( array( 'wti_get_unlike' => 'log' ) ); ?>" id="<?php echo $this->field_id( array( 'wti_get_unlike' => 'log' ) ); ?>" value="<?php echo esc_attr( $prefs['wti_get_unlike']['log'] ); ?>" class="long" /></div>
					<span class="description"><?php echo $this->available_template_tags( array( 'general' ) ); ?></span>
				</li>
			</ol>
			<?php
		}
		
		/**
		 * Sanitise Preferences
		 *
		 * @since 		2.3
		 */
		function sanitise_preferences( $data ) {

			if ( isset( $data['wti_add_like']['limit'] ) && isset( $data['wti_add_like']['limit_by'] ) ) {
				$limit = sanitize_text_field( $data['wti_add_like']['limit'] );

				if ( $limit == '' ) $limit = 0;
				
				$data['wti_add_like']['limit'] = $limit . '/' . $data['wti_add_like']['limit_by'];
				unset( $data['wti_add_like']['limit_by'] );
			}

			if ( isset( $data['wti_get_like']['limit'] ) && isset( $data['wti_get_like']['limit_by'] ) ) {
				$limit = sanitize_text_field( $data['wti_get_like']['limit'] );
				
				if ( $limit == '' ) $limit = 0;
				
				$data['wti_get_like']['limit'] = $limit . '/' . $data['wti_get_like']['limit_by'];
				unset( $data['wti_get_like']['limit_by'] );
			}

			return $data;
		}
	}
endif;